@@ -803,7 +803,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         channel_id = self.get_channel(feed_slug)["id"]
 
-        url = self._base_url_ch+"/"+channel_id+"/feed?page=0&limit=100&agentId="+self._agentId
+        url = self._base_url_ch+"/channels"+channel_id+"/messages"
 
         s = requests.Session()
         s.keep_alive = False
@@ -818,7 +818,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         slugs = []
 
         for card in cards:
-            if card["id"] is not "_system-highlight":
+            if card["id"] != "_system-highlight":
                 slugs.append(card["insightSlug"])
 
         return slugs
