@@ -119,32 +119,31 @@ class Insight_Definition:
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
         columns=[]
         for query in query_ids:
-            if (not query.startswith("qcomp")):
 
-                url = self._base_url_askdata + "/smartinsight/definitions/" + self.definition_id + "/queries/" + query.lower() + "/columns"
+            url = self._base_url_askdata + "/smartinsight/definitions/" + self.definition_id + "/queries/" + query.lower() + "/columns"
+            r = self.__make_get_request(url)
+            cols = r.json()
+
+            while (cols == []):
                 r = self.__make_get_request(url)
                 cols = r.json()
 
-                while (cols == []):
-                    r = self.__make_get_request(url)
-                    cols = r.json()
+            ''' else:
+             qc = self.get_component(query)
 
-            else:
-                qc = self.get_component(query)
+             url_preview = self.smart_insight_url + "/composed_queries/" + qc["settings"][
+                 "qc"] + "/preview?limit=100&agentId=" + self.agent_id
 
-                url_preview = self.smart_insight_url + "/composed_queries/" + qc["settings"][
-                    "qc"] + "/preview?limit=100&agentId=" + self.agent_id
+             s = requests.Session()
+             s.keep_alive = False
+             retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+             s.mount('https://', HTTPAdapter(max_retries=retries))
 
-                s = requests.Session()
-                s.keep_alive = False
-                retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-                s.mount('https://', HTTPAdapter(max_retries=retries))
-
-                headers = {"Authorization": "Bearer" + " " + self._token}
-                response = s.post(url=url_preview, json={}, headers=headers)
-                response.raise_for_status()
-                r = response.json()
-                cols = r["schema"]
+             headers = {"Authorization": "Bearer" + " " + self._token}
+             response = s.post(url=url_preview, json={}, headers=headers)
+             response.raise_for_status()
+             r = response.json()
+             cols = r["schema"]'''
 
             for col in cols:
                 columns.append(col)
